@@ -29,6 +29,6 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-__version__ = '3.8'
-__author__ = 'Hsiaoming Yang <lepture@me.com>'
+__version__ = '3.8.1'
+__author__ = 'Hsiaoming Yang <me@liquidluck.com>'
 __homepage__ = 'http://lab.lepture.com/liquidluck/'
